##  Creating Additional S-User Administrators
### Context
Administrators can duplicate their own S-user authorizations to create new administrator S-user IDs.
**Tip**
SAP recommends creating at least two additional S-user administrators.
To create additional S-user administrators, follow the instructions in [Cloning S-User ID Authorizations](https://help.sap.com/docs/leanix/ea/creating-and-managing-s-users-in-sap-for-me?locale=en-US&state=PRODUCTION&version=CLOUD#task_b2t_2fk_fgc).
YesNo
Send
